@@ -27,7 +27,8 @@ except ImportError:
         import json as simplejson
 
 
-EPOCH = time.mktime((2011, 1, 1, 0, 0, 0, 0, 0, 0))
+# 2011/01/01 in UTC
+EPOCH = 1293840000
 
 
 def constant_time_compare(val1, val2):
@@ -271,8 +272,12 @@ class TimedSerializer(Serializer):
         which is a subclass of :exc:`BadSignature`.  All arguments are
         forwarded to the signer's :meth:`~TimestampSigner.unsign` method.
         """
-        base64d = self.make_signer().unsign(s, max_age, return_timestamp)
-        return self.load_payload(base64d)
+        if return_timestamp:
+            base64d, timestamp = self.make_signer().unsign(s, max_age, return_timestamp)
+            return self.load_payload(base64d), timestamp
+        else:
+            base64d = self.make_signer().unsign(s, max_age, return_timestamp)
+            return self.load_payload(base64d)
 
 
 class URLSafeSerializerMixin(object):
